summaryrefslogtreecommitdiff
path: root/mpfr/set_dfl_prec.c
diff options
context:
space:
mode:
Diffstat (limited to 'mpfr/set_dfl_prec.c')
-rw-r--r--mpfr/set_dfl_prec.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/mpfr/set_dfl_prec.c b/mpfr/set_dfl_prec.c
index c61875793..27ae0cd1a 100644
--- a/mpfr/set_dfl_prec.c
+++ b/mpfr/set_dfl_prec.c
@@ -24,8 +24,8 @@ MA 02111-1307, USA. */
#include "mpfr.h"
#include "mpfr-impl.h"
-/* default is 53 bits */
-mp_prec_t __gmpfr_default_fp_bit_precision = 53;
+/* default is IEEE double precision, i.e. 53 bits */
+mp_prec_t __gmpfr_default_fp_bit_precision = IEEE_DBL_MANT_DIG;
void
mpfr_set_default_prec (mp_prec_t prec)